@@ -16,18 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -54,16 +54,17 @@ from google.api import system_parameter_pb2  # type: ignore
 from google.api import usage_pb2  # type: ignore
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.servicemanagement_v1.services.service_manager import pagers
-from google.cloud.servicemanagement_v1.types import resources
-from google.cloud.servicemanagement_v1.types import servicemanager
 from google.protobuf import any_pb2  # type: ignore
 from google.protobuf import api_pb2  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 from google.protobuf import type_pb2  # type: ignore
 from google.protobuf import wrappers_pb2  # type: ignore
-from .transports.base import ServiceManagerTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.servicemanagement_v1.services.service_manager import pagers
+from google.cloud.servicemanagement_v1.types import resources, servicemanager
+
+from .transports.base import DEFAULT_CLIENT_INFO, ServiceManagerTransport
 from .transports.grpc import ServiceManagerGrpcTransport
 from .transports.grpc_asyncio import ServiceManagerGrpcAsyncIOTransport
 
@@ -82,7 +83,10 @@ class ServiceManagerClientMeta(type):
     _transport_registry["grpc"] = ServiceManagerGrpcTransport
     _transport_registry["grpc_asyncio"] = ServiceManagerGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[ServiceManagerTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[ServiceManagerTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -102,7 +106,9 @@ class ServiceManagerClientMeta(type):
 
 
 class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
-    """`Google Service Management API </service-management/overview>`__"""
+    """`Google Service Management
+    API <https://cloud.google.com/service-infrastructure/docs/overview>`__
+    """
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
@@ -187,7 +193,9 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         return self._transport
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -200,9 +208,13 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -211,9 +223,13 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -222,9 +238,13 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -233,10 +253,14 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -425,7 +449,6 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         also returns all services the calling user has
         "servicemanagement.services.get" permission for.
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
@@ -509,12 +532,20 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.list_services]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListServicesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -532,7 +563,6 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         r"""Gets a managed service. Authentication is required
         unless the service is public.
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
@@ -602,8 +632,21 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get_service]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("service_name", request.service_name),)
+            ),
+        )
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -629,7 +672,6 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
 
         Operation<response: ManagedService>
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
@@ -703,7 +745,12 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.create_service]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -734,7 +781,6 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
 
         Operation<response: google.protobuf.Empty>
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
@@ -764,8 +810,9 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
                 method.
             service_name (str):
                 Required. The name of the service. See the
-                `overview </service-management/overview>`__ for naming
-                requirements. For example: ``example.googleapis.com``.
+                `overview <https://cloud.google.com/service-infrastructure/docs/overview>`__
+                for naming requirements. For example:
+                ``example.googleapis.com``.
 
                 This corresponds to the ``service_name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -820,8 +867,21 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.delete_service]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("service_name", request.service_name),)
+            ),
+        )
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -851,7 +911,6 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
 
         Operation<response: UndeleteServiceResponse>
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
@@ -881,8 +940,9 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
                 method.
             service_name (str):
                 Required. The name of the service. See the
-                `overview </service-management/overview>`__ for naming
-                requirements. For example: ``example.googleapis.com``.
+                `overview <https://cloud.google.com/service-infrastructure/docs/overview>`__
+                for naming requirements. For example:
+                ``example.googleapis.com``.
 
                 This corresponds to the ``service_name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -927,8 +987,21 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.undelete_service]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("service_name", request.service_name),)
+            ),
+        )
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -953,7 +1026,6 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         r"""Lists the history of the service configuration for a
         managed service, from the newest to the oldest.
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
@@ -980,8 +1052,9 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
                 ListServiceConfigs method.
             service_name (str):
                 Required. The name of the service. See the
-                `overview </service-management/overview>`__ for naming
-                requirements. For example: ``example.googleapis.com``.
+                `overview <https://cloud.google.com/service-infrastructure/docs/overview>`__
+                for naming requirements. For example:
+                ``example.googleapis.com``.
 
                 This corresponds to the ``service_name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1026,13 +1099,29 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list_service_configs]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("service_name", request.service_name),)
+            ),
+        )
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListServiceConfigsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1052,7 +1141,6 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         r"""Gets a service configuration (version) for a managed
         service.
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
@@ -1079,8 +1167,9 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
                 method.
             service_name (str):
                 Required. The name of the service. See the
-                `overview </service-management/overview>`__ for naming
-                requirements. For example: ``example.googleapis.com``.
+                `overview <https://cloud.google.com/service-infrastructure/docs/overview>`__
+                for naming requirements. For example:
+                ``example.googleapis.com``.
 
                 This corresponds to the ``service_name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1160,8 +1249,24 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get_service_config]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("service_name", request.service_name),
+                    ("config_id", request.config_id),
+                )
+            ),
+        )
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1186,7 +1291,6 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         referenced by existing rollouts are kept for each service. The
         rest will be deleted eventually.
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
@@ -1212,8 +1316,9 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
                 CreateServiceConfig method.
             service_name (str):
                 Required. The name of the service. See the
-                `overview </service-management/overview>`__ for naming
-                requirements. For example: ``example.googleapis.com``.
+                `overview <https://cloud.google.com/service-infrastructure/docs/overview>`__
+                for naming requirements. For example:
+                ``example.googleapis.com``.
 
                 This corresponds to the ``service_name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1281,8 +1386,21 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.create_service_config]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("service_name", request.service_name),)
+            ),
+        )
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1312,7 +1430,6 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
 
         Operation<response: SubmitConfigSourceResponse>
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
@@ -1342,8 +1459,9 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
                 SubmitConfigSource method.
             service_name (str):
                 Required. The name of the service. See the
-                `overview </service-management/overview>`__ for naming
-                requirements. For example: ``example.googleapis.com``.
+                `overview <https://cloud.google.com/service-infrastructure/docs/overview>`__
+                for naming requirements. For example:
+                ``example.googleapis.com``.
 
                 This corresponds to the ``service_name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1408,8 +1526,21 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.submit_config_source]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("service_name", request.service_name),)
+            ),
+        )
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1436,7 +1567,6 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         rollouts for a managed service, from the newest to the
         oldest.
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
@@ -1464,8 +1594,9 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
                 'ListServiceRollouts'
             service_name (str):
                 Required. The name of the service. See the
-                `overview </service-management/overview>`__ for naming
-                requirements. For example: ``example.googleapis.com``.
+                `overview <https://cloud.google.com/service-infrastructure/docs/overview>`__
+                for naming requirements. For example:
+                ``example.googleapis.com``.
 
                 This corresponds to the ``service_name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1473,11 +1604,11 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
             filter (str):
                 Required. Use ``filter`` to return subset of rollouts.
                 The following filters are supported: -- To limit the
-                results to only those in
-                `status <google.api.servicemanagement.v1.RolloutStatus>`__
+                results to only those in status
+                (google.api.servicemanagement.v1.RolloutStatus)
                 'SUCCESS', use filter='status=SUCCESS' -- To limit the
-                results to those in
-                `status <google.api.servicemanagement.v1.RolloutStatus>`__
+                results to those in status
+                (google.api.servicemanagement.v1.RolloutStatus)
                 'CANCELLED' or 'FAILED', use filter='status=CANCELLED OR
                 status=FAILED'
 
@@ -1526,13 +1657,29 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list_service_rollouts]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("service_name", request.service_name),)
+            ),
+        )
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListServiceRolloutsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1551,7 +1698,6 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         r"""Gets a service configuration
         [rollout][google.api.servicemanagement.v1.Rollout].
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
@@ -1578,8 +1724,9 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
                 GetServiceRollout method.
             service_name (str):
                 Required. The name of the service. See the
-                `overview </service-management/overview>`__ for naming
-                requirements. For example: ``example.googleapis.com``.
+                `overview <https://cloud.google.com/service-infrastructure/docs/overview>`__
+                for naming requirements. For example:
+                ``example.googleapis.com``.
 
                 This corresponds to the ``service_name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1634,8 +1781,24 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get_service_rollout]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("service_name", request.service_name),
+                    ("rollout_id", request.rollout_id),
+                )
+            ),
+        )
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1668,7 +1831,6 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
 
         Operation<response: Rollout>
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
@@ -1698,8 +1860,9 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
                 'CreateServiceRollout'
             service_name (str):
                 Required. The name of the service. See the
-                `overview </service-management/overview>`__ for naming
-                requirements. For example: ``example.googleapis.com``.
+                `overview <https://cloud.google.com/service-infrastructure/docs/overview>`__
+                for naming requirements. For example:
+                ``example.googleapis.com``.
 
                 This corresponds to the ``service_name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1754,8 +1917,21 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.create_service_rollout]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("service_name", request.service_name),)
+            ),
+        )
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1791,7 +1967,6 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         method will compare GenerateConfigReportRequest.new_value with
         the last pushed service configuration.
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
@@ -1876,7 +2051,12 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.generate_config_report]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
