@@ -15,21 +15,19 @@
 #
 import abc
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
-import pkg_resources
-
-import google.auth  # type: ignore
-import google.api_core
-from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
-from google.api_core import retry as retries
-from google.api_core import operations_v1
-from google.auth import credentials as ga_credentials  # type: ignore
-from google.oauth2 import service_account  # type: ignore
 
 from google.api import service_pb2  # type: ignore
-from google.cloud.servicemanagement_v1.types import resources
-from google.cloud.servicemanagement_v1.types import servicemanager
+import google.api_core
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1, operations_v1
+from google.api_core import retry as retries
+import google.auth  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.longrunning import operations_pb2  # type: ignore
+from google.oauth2 import service_account  # type: ignore
+import pkg_resources
+
+from google.cloud.servicemanagement_v1.types import resources, servicemanager
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
@@ -89,6 +87,7 @@ class ServiceManagerTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
+
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
             host += ":443"
@@ -130,19 +129,29 @@ class ServiceManagerTransport(abc.ABC):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
             self.list_services: gapic_v1.method.wrap_method(
-                self.list_services, default_timeout=None, client_info=client_info,
+                self.list_services,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.get_service: gapic_v1.method.wrap_method(
-                self.get_service, default_timeout=None, client_info=client_info,
+                self.get_service,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.create_service: gapic_v1.method.wrap_method(
-                self.create_service, default_timeout=None, client_info=client_info,
+                self.create_service,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.delete_service: gapic_v1.method.wrap_method(
-                self.delete_service, default_timeout=None, client_info=client_info,
+                self.delete_service,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.undelete_service: gapic_v1.method.wrap_method(
-                self.undelete_service, default_timeout=None, client_info=client_info,
+                self.undelete_service,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.list_service_configs: gapic_v1.method.wrap_method(
                 self.list_service_configs,
@@ -150,7 +159,9 @@ class ServiceManagerTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.get_service_config: gapic_v1.method.wrap_method(
-                self.get_service_config, default_timeout=None, client_info=client_info,
+                self.get_service_config,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.create_service_config: gapic_v1.method.wrap_method(
                 self.create_service_config,
@@ -168,7 +179,9 @@ class ServiceManagerTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.get_service_rollout: gapic_v1.method.wrap_method(
-                self.get_service_rollout, default_timeout=None, client_info=client_info,
+                self.get_service_rollout,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.create_service_rollout: gapic_v1.method.wrap_method(
                 self.create_service_rollout,
@@ -185,9 +198,9 @@ class ServiceManagerTransport(abc.ABC):
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -325,5 +338,9 @@ class ServiceManagerTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("ServiceManagerTransport",)
